@@ -1,7 +1,7 @@
 package Perinci::Result::Format::Lite;
 
-our $DATE = '2016-12-12'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2016-12-29'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use 5.010001;
 #IFUNBUILT
@@ -356,8 +356,8 @@ sub __gen_table {
             }
             push @res, " </tr>\n";
             push @res, "</thead>\n" if $i == 0;
-            push @res, "</tbody>\n" if $i == 1;
         }
+        push @res, "</tbody>\n";
         push @res, "</table>\n";
         join '', @res;
     } else {
@@ -449,6 +449,407 @@ sub format {
     }
 }
 
+# BEGIN FATPACK CODE: Data/Check/Structure.pm Text/Table/Any.pm Text/Table/Tiny.pm
+{
+    no strict 'refs';
+    $main::fatpacked{"Data/Check/Structure.pm"} = '##line '.(1+__LINE__).' "'.__FILE__."\"\n".<<'DATA_CHECK_STRUCTURE';
+#package Data::Check::Structure;
+#
+#our $DATE = '2014-07-14'; 
+#our $VERSION = '0.03'; 
+#
+#use 5.010001;
+#use strict;
+#use warnings;
+#
+#require Exporter;
+#our @ISA = qw(Exporter);
+#our @EXPORT_OK = qw(
+#                       is_aoa
+#                       is_aoaos
+#                       is_aoh
+#                       is_aohos
+#                       is_aos
+#                       is_hoa
+#                       is_hoaos
+#                       is_hoh
+#                       is_hohos
+#                       is_hos
+#               );
+#
+#sub is_aos {
+#    my ($data, $opts) = @_;
+#    $opts //= {};
+#    my $max = $opts->{max};
+#
+#    return 0 unless ref($data) eq 'ARRAY';
+#    for my $i (0..@$data-1) {
+#        last if defined($max) && $i >= $max;
+#        return 0 if ref($data->[$i]);
+#    }
+#    1;
+#}
+#
+#sub is_aoa {
+#    my ($data, $opts) = @_;
+#    $opts //= {};
+#    my $max = $opts->{max};
+#
+#    return 0 unless ref($data) eq 'ARRAY';
+#    for my $i (0..@$data-1) {
+#        last if defined($max) && $i >= $max;
+#        return 0 unless ref($data->[$i]) eq 'ARRAY';
+#    }
+#    1;
+#}
+#
+#sub is_aoaos {
+#    my ($data, $opts) = @_;
+#    $opts //= {};
+#    my $max = $opts->{max};
+#
+#    return 0 unless ref($data) eq 'ARRAY';
+#    my $aos_opts = {max=>$max};
+#    for my $i (0..@$data-1) {
+#        last if defined($max) && $i >= $max;
+#        return 0 unless is_aos($data->[$i], $aos_opts);
+#    }
+#    1;
+#}
+#
+#sub is_aoh {
+#    my ($data, $opts) = @_;
+#    $opts //= {};
+#    my $max = $opts->{max};
+#
+#    return 0 unless ref($data) eq 'ARRAY';
+#    for my $i (0..@$data-1) {
+#        last if defined($max) && $i >= $max;
+#        return 0 unless ref($data->[$i]) eq 'HASH';
+#    }
+#    1;
+#}
+#
+#sub is_aohos {
+#    my ($data, $opts) = @_;
+#    $opts //= {};
+#    my $max = $opts->{max};
+#
+#    return 0 unless ref($data) eq 'ARRAY';
+#    my $hos_opts = {max=>$max};
+#    for my $i (0..@$data-1) {
+#        last if defined($max) && $i >= $max;
+#        return 0 unless is_hos($data->[$i], $hos_opts);
+#    }
+#    1;
+#}
+#
+#sub is_hos {
+#    my ($data, $opts) = @_;
+#    $opts //= {};
+#    my $max = $opts->{max};
+#
+#    return 0 unless ref($data) eq 'HASH';
+#    my $i = 0;
+#    for my $k (keys %$data) {
+#        last if defined($max) && ++$i >= $max;
+#        return 0 if ref($data->{$k});
+#    }
+#    1;
+#}
+#
+#sub is_hoa {
+#    my ($data, $opts) = @_;
+#    $opts //= {};
+#    my $max = $opts->{max};
+#
+#    return 0 unless ref($data) eq 'HASH';
+#    my $i = 0;
+#    for my $k (keys %$data) {
+#        last if defined($max) && ++$i >= $max;
+#        return 0 unless ref($data->{$k}) eq 'ARRAY';
+#    }
+#    1;
+#}
+#
+#sub is_hoaos {
+#    my ($data, $opts) = @_;
+#    $opts //= {};
+#    my $max = $opts->{max};
+#
+#    return 0 unless ref($data) eq 'HASH';
+#    my $i = 0;
+#    for my $k (keys %$data) {
+#        last if defined($max) && ++$i >= $max;
+#        return 0 unless is_aos($data->{$k});
+#    }
+#    1;
+#}
+#
+#sub is_hoh {
+#    my ($data, $opts) = @_;
+#    $opts //= {};
+#    my $max = $opts->{max};
+#
+#    return 0 unless ref($data) eq 'HASH';
+#    my $i = 0;
+#    for my $k (keys %$data) {
+#        last if defined($max) && ++$i >= $max;
+#        return 0 unless ref($data->{$k}) eq 'HASH';
+#    }
+#    1;
+#}
+#
+#sub is_hohos {
+#    my ($data, $opts) = @_;
+#    $opts //= {};
+#    my $max = $opts->{max};
+#
+#    return 0 unless ref($data) eq 'HASH';
+#    my $i = 0;
+#    for my $k (keys %$data) {
+#        last if defined($max) && ++$i >= $max;
+#        return 0 unless is_hos($data->{$k});
+#    }
+#    1;
+#}
+#
+#1;
+#
+#__END__
+#
+DATA_CHECK_STRUCTURE
+
+    $main::fatpacked{"Text/Table/Any.pm"} = '##line '.(1+__LINE__).' "'.__FILE__."\"\n".<<'TEXT_TABLE_ANY';
+#package Text::Table::Any;
+#
+#our $DATE = '2016-12-29'; 
+#our $VERSION = '0.06'; 
+#
+#
+#sub _encode {
+#    my $val = shift;
+#    $val =~ s/([\\"])/\\$1/g;
+#    "\"$val\"";
+#}
+#
+#sub table {
+#    my %params = @_;
+#
+#    my $rows       = $params{rows} or die "Must provide rows!";
+#    my $backend    = $params{backend} || 'Text::Table::Tiny';
+#    my $header_row = $params{header_row} // 0;
+#
+#    if ($backend eq 'Text::Table::Tiny') {
+#        require Text::Table::Tiny;
+#        return Text::Table::Tiny::table(
+#            rows => $rows, header_row => $header_row) . "\n";
+#    } elsif ($backend eq 'Text::Table::TinyColor') {
+#        require Text::Table::TinyColor;
+#        return Text::Table::TinyColor::table(
+#            rows => $rows, header_row => $header_row) . "\n";
+#    } elsif ($backend eq 'Text::Table::TinyColorWide') {
+#        require Text::Table::TinyColorWide;
+#        return Text::Table::TinyColorWide::table(
+#            rows => $rows, header_row => $header_row) . "\n";
+#    } elsif ($backend eq 'Text::Table::TinyWide') {
+#        require Text::Table::TinyWide;
+#        return Text::Table::TinyWide::table(
+#            rows => $rows, header_row => $header_row) . "\n";
+#    } elsif ($backend eq 'Text::Table::Org') {
+#        require Text::Table::Org;
+#        return Text::Table::Org::table(
+#            rows => $rows, header_row => $header_row);
+#    } elsif ($backend eq 'Text::Table::CSV') {
+#        require Text::Table::CSV;
+#        return Text::Table::CSV::table(
+#            rows => $rows);
+#    } elsif ($backend eq 'Text::Table::HTML') {
+#        require Text::Table::HTML;
+#        return Text::Table::HTML::table(
+#            rows => $rows, header_row => $header_row);
+#    } elsif ($backend eq 'Text::Table::HTML::DataTables') {
+#        require Text::Table::HTML::DataTables;
+#        return Text::Table::HTML::DataTables::table(
+#            rows => $rows, header_row => $header_row);
+#    } elsif ($backend eq 'Text::ANSITable') {
+#        require Text::ANSITable;
+#        my $t = Text::ANSITable->new(
+#            use_utf8 => 0,
+#            use_box_chars => 0,
+#            use_color => 0,
+#            border_style => 'Default::single_ascii',
+#        );
+#        if ($header_row) {
+#            $t->columns($rows->[0]);
+#            $t->add_row($rows->[$_]) for 1..@$rows-1;
+#        } else {
+#            $t->columns([ map {"col$_"} 0..$#{$rows->[0]} ]);
+#            $t->add_row($_) for @$rows;
+#        }
+#        return $t->draw;
+#    } elsif ($backend eq 'Text::ASCIITable') {
+#        require Text::ASCIITable;
+#        my $t = Text::ASCIITable->new();
+#        if ($header_row) {
+#            $t->setCols(@{ $rows->[0] });
+#            $t->addRow(@{ $rows->[$_] }) for 1..@$rows-1;
+#        } else {
+#            $t->setCols(map { "col$_" } 0..$#{ $rows->[0] });
+#            $t->addRow(@$_) for @$rows;
+#        }
+#        return "$t";
+#    } elsif ($backend eq 'Text::FormatTable') {
+#        require Text::FormatTable;
+#        my $t = Text::FormatTable->new(join('|', ('l') x @{ $rows->[0] }));
+#        $t->head(@{ $rows->[0] });
+#        $t->row(@{ $rows->[$_] }) for 1..@$rows-1;
+#        return $t->render;
+#    } elsif ($backend eq 'Text::MarkdownTable') {
+#        require Text::MarkdownTable;
+#        my $out = "";
+#        my $fields =  $header_row ?
+#            $rows->[0] : [map {"col$_"} 0..$#{ $rows->[0] }];
+#        my $t = Text::MarkdownTable->new(file => \$out, columns => $fields);
+#        foreach (($header_row ? 1:0) .. $#{$rows}) {
+#            my $row = $rows->[$_];
+#            $t->add( {
+#                map { $fields->[$_] => $row->[$_] } 0..@$fields-1
+#            });
+#        }
+#        $t->done;
+#        return $out;
+#    } elsif ($backend eq 'Text::Table') {
+#        require Text::Table;
+#        my $t = Text::Table->new(@{ $rows->[0] });
+#        $t->load(@{ $rows }[1..@$rows-1]);
+#        return $t;
+#    } elsif ($backend eq 'Text::TabularDisplay') {
+#        require Text::TabularDisplay;
+#        my $t = Text::TabularDisplay->new(@{ $rows->[0] });
+#        $t->add(@{ $rows->[$_] }) for 1..@$rows-1;
+#        return $t->render . "\n";
+#    } else {
+#        die "Unknown backend '$backend'";
+#    }
+#}
+#
+#1;
+#
+#__END__
+#
+TEXT_TABLE_ANY
+
+    $main::fatpacked{"Text/Table/Tiny.pm"} = '##line '.(1+__LINE__).' "'.__FILE__."\"\n".<<'TEXT_TABLE_TINY';
+#use 5.006;
+#use strict;
+#use warnings;
+#package Text::Table::Tiny;
+#$Text::Table::Tiny::VERSION = '0.04';
+#use parent 'Exporter';
+#use List::Util qw();
+#
+#our @EXPORT_OK = qw/ generate_table /;
+#
+#
+#
+#our $COLUMN_SEPARATOR = '|';
+#our $ROW_SEPARATOR = '-';
+#our $CORNER_MARKER = '+';
+#our $HEADER_ROW_SEPARATOR = '=';
+#our $HEADER_CORNER_MARKER = 'O';
+#
+#sub generate_table {
+#
+#    my %params = @_;
+#    my $rows = $params{rows} or die "Must provide rows!";
+#
+#    my $widths = _maxwidths($rows);
+#    my $max_index = _max_array_index($rows);
+#
+#    my $format = _get_format($widths);
+#    my $row_sep = _get_row_separator($widths);
+#    my $head_row_sep = _get_header_row_separator($widths);
+#
+#    my @table;
+#    push @table, $row_sep;
+#
+#    my $data_begins = 0;
+#    if ( $params{header_row} ) {
+#        my $header_row = $rows->[0];
+#        $data_begins++;
+#        push @table, sprintf(
+#                         $format, 
+#                         map { defined($header_row->[$_]) ? $header_row->[$_] : '' } (0..$max_index)
+#                     );
+#        push @table, $params{separate_rows} ? $head_row_sep : $row_sep;
+#    }
+#
+#    foreach my $row ( @{ $rows }[$data_begins..$#$rows] ) {
+#        push @table, sprintf(
+#	    $format, 
+#	    map { defined($row->[$_]) ? $row->[$_] : '' } (0..$max_index)
+#	);
+#        push @table, $row_sep if $params{separate_rows};
+#    }
+#
+#    push @table, $row_sep unless $params{separate_rows};
+#    return join("\n",grep {$_} @table);
+#}
+#
+#sub _get_cols_and_rows ($) {
+#    my $rows = shift;
+#    return ( List::Util::max( map { scalar @$_ } @$rows), scalar @$rows);
+#}
+#
+#sub _maxwidths {
+#    my $rows = shift;
+#    my $max_index = _max_array_index($rows);
+#    my $widths = [];
+#    for my $i (0..$max_index) {
+#        my $max = List::Util::max(map {defined $$_[$i] ? length($$_[$i]) : 0} @$rows);
+#        push @$widths, $max;
+#    }
+#    return $widths;
+#}
+#
+#sub _max_array_index {
+#    my $rows = shift;
+#    return List::Util::max( map { $#$_ } @$rows );
+#}
+#
+#sub _get_format {
+#    my $widths = shift;
+#    return "$COLUMN_SEPARATOR ".join(" $COLUMN_SEPARATOR ",map { "%-${_}s" } @$widths)." $COLUMN_SEPARATOR";
+#}
+#
+#sub _get_row_separator {
+#    my $widths = shift;
+#    return "$CORNER_MARKER$ROW_SEPARATOR".join("$ROW_SEPARATOR$CORNER_MARKER$ROW_SEPARATOR",map { $ROW_SEPARATOR x $_ } @$widths)."$ROW_SEPARATOR$CORNER_MARKER";
+#}
+#
+#sub _get_header_row_separator {
+#    my $widths = shift;
+#    return "$HEADER_CORNER_MARKER$HEADER_ROW_SEPARATOR".join("$HEADER_ROW_SEPARATOR$HEADER_CORNER_MARKER$HEADER_ROW_SEPARATOR",map { $HEADER_ROW_SEPARATOR x $_ } @$widths)."$HEADER_ROW_SEPARATOR$HEADER_CORNER_MARKER";
+#}
+#
+#*table = \&generate_table;
+#
+#1;
+#
+#__END__
+#
+#
+TEXT_TABLE_TINY
+
+    $main::fatpacked{$_} =~ s/^\#//mg for ('Data/Check/Structure.pm', 'Text/Table/Any.pm', 'Text/Table/Tiny.pm');
+    my $class = 'FatPacked::'.(0+\%main::fatpacked);
+    unless (defined &{"${class}::INC"}) { if ($] < 5.008) { *{"${class}::INC"} = sub { if (my $fat = $_[0]{$_[1]}) { return sub { return 0 unless length $fat; $fat =~ s/^([^\n]*\n?)//; $_ = $1; return 1; }; } return; }; } else { *{"${class}::INC"} = sub { if (my $fat = $_[0]{$_[1]}) { open my $fh, '<', \$fat or die "FatPacker error loading $_[1] (could be a perl installation issue?)"; return $fh; } return; }; } }
+    my $hook = bless(\%main::fatpacked, $class);
+    push @INC, $hook unless grep {ref($_) && "$_" eq "$hook"} @INC;
+}
+# END OF FATPACK CODE
+
 1;
 # ABSTRACT: Format enveloped result
 
@@ -464,7 +865,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.21 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-12-12.
+This document describes version 0.22 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-12-29.
 
 =head1 SYNOPSIS
 
